==> couch-joiner-1.0.1.jar: joiner/main.clj <==
(ns joiner.main
  (:gen-class)
  (:use [com.ashafa.clutch]
        [joiner.core]
        [joiner.user]
        [clojure.data.json]
        [clojure.tools.cli]))


(defn- update-doc [id doc file]
  (let [existing (get-document (:_id (merge {:_id id} doc)))
        updated-doc (if (empty? doc)
                      ;;If document is empty - don't bother updating it
                      existing
                      (update-document (merge existing doc)))]
    (if (nil? file)
      updated-doc
      (put-attachment updated-doc file))))

(defn -main [& args]
  (let [arguments (cli args
                       (required ["-db" "--database" "Database"])
                       (required ["-op" "--operation" "Operation: get, save, update or delete"])
                       (optional ["-id" "--document-id" "Document ID"])
                       (optional ["-d" "--document" "Document" :default "{}"])
                       (optional ["-f" "--file" "File"]))]
    (with-db (authenticated-database (:database arguments))
             (let [doc (:document arguments)
                   json-doc (if doc (read-json doc))
                   id (:document-id arguments)
                   op (:operation arguments)]
               (println
                 (case (keyword op)
                   :get (get-document id)
                   :save (put-document json-doc)
                   :update (update-doc id json-doc (:file arguments))
                   :delete (delete-document json-doc)
                   (str "Unknown operation " op)))))))

==> couch-joiner-1.1.0.jar: joiner/main.clj <==
(ns joiner.main
  (:gen-class)
  (:use [joiner.core]
        [joiner.user]
        [com.ashafa.clutch :only (update-document get-database
                                   put-document get-document
                                   put-attachment with-db
                                   delete-document)]
        [clojure.data.json]
        [clojure.tools.cli]))


(defn- update-doc [id doc file]
  (let [existing (get-document (:_id (merge {:_id id} doc)))
        updated-doc (if (empty? doc)
                      ;;If document is empty - don't bother updating it
                      existing
                      (update-document (merge existing doc)))]
    (if (nil? file)
      updated-doc
      (put-attachment updated-doc file))))

(defn -main [& args]
  (let [arguments (cli args
                       (required ["-db" "--database" "Database"])
                       (required ["-op" "--operation" "Operation: get, save, update or delete"])
                       (optional ["-id" "--document-id" "Document ID"])
                       (optional ["-d" "--document" "Document" :default "{}"])
                       (optional ["-f" "--file" "File"]))]
    (with-db (authenticated-database (:database arguments))
             (let [doc (:document arguments)
                   json-doc (if doc (read-json doc))
                   id (:document-id arguments)
                   op (:operation arguments)]
               (println
                 (case (keyword op)
                   :get (get-document id)
                   :save (put-document json-doc)
                   :update (update-doc id json-doc (:file arguments))
                   :delete (delete-document json-doc)
                   (str "Unknown operation " op)))))))
